# sage_setup: distribution = sagemath-repl
"""
Tests Deprecation

EXAMPLES::

    sage: import sage.tests.test_deprecation
    sage: sage.tests.test_deprecation.function_old()
    doctest:...: DeprecationWarning: function_old is deprecated. Please
    use sage.tests.test_deprecation.function_new instead.
    See https://github.com/sagemath/sage/issues/12345 for details.
"""
from sage.misc.superseded import deprecated_function_alias


def function_new():
    """
    New function, deprecating ``old_function``.

    EXAMPLES::

        sage: from sage.tests.test_deprecation import function_old
        sage: function_old()
        doctest:...: DeprecationWarning: function_old is deprecated. Please
        use sage.tests.test_deprecation.function_new instead.
        See https://github.com/sagemath/sage/issues/12345 for details.
    """
    pass


function_old = deprecated_function_alias(12345, function_new)



# sage_setup: distribution = sagemath-repl
"get_remote_file"
import os
from pathlib import Path
from urllib.request import Request, urlopen
from ssl import create_default_context as default_context


def get_remote_file(filename, verbose=True) -> Path:
    """
    INPUT:

    - ``filename`` -- the URL of a file on the web, e.g.,
      ``'http://modular.math.washington.edu/myfile.txt'``

    - ``verbose`` -- whether to display download status

    OUTPUT:

    This creates a file in the temp directory and returns the absolute path
    to that file as a :class:`Path` object.

    EXAMPLES::

        sage: url = 'https://www.sagemath.org/files/loadtest.py'
        sage: g = get_remote_file(url, verbose=False)      # optional - internet
        sage: with open(g) as f: print(f.read())           # optional - internet
        print("hi from the net")
        <BLANKLINE>
        print(2 + 3)
    """
    if verbose:
        print("Attempting to load remote file: " + filename)

    from sage.misc.temporary_file import tmp_filename
    ext = os.path.splitext(filename)[1]
    temp_name = Path(tmp_filename(ext=ext))
    # IMPORTANT -- urllib takes a long time to load,
    # so do not import it in the module scope.

    req = Request(filename, headers={"User-Agent": "sage-doctest"})

    if verbose:
        print("Loading started")

    content = urlopen(req, timeout=1, context=default_context())
    with temp_name.open('wb') as f:
        f.write(content.read())

    if verbose:
        print("Loading ended")

    return temp_name



# sage_setup: distribution = sagemath-repl
r"""
Ensure that ``functools.partial`` is correctly handled by
:func:`~sage.misc.sageinspect.sage_getsourcelines`.
"""
from functools import partial


def base(x):
    """
    Test function to make sure
    :func:`~sage.misc.sageinspect.sage_getsourcelines` can get
    the code of a function created by ``functools.partial``.

    EXAMPLES::

        sage: from sage.tests.functools_partial_src import base, test_func
        sage: base(3)
        21
        sage: test_func()
        42
    """
    x = x * 7
    return x


test_func = partial(base, 6)
